
# Slot: process positively regulates process




URI: [biolink:process_positively_regulates_process](https://w3id.org/biolink/vocab/process_positively_regulates_process)


## Domain and Range

[Occurrent](Occurrent.md) &#8594;  <sub>0..\*</sub> [Occurrent](Occurrent.md)

## Parents

 *  is_a: [process regulates process](process_regulates_process.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | RO:0002213 |

